@@ -2,10 +2,10 @@
 /*
 ################################################################################
 #
-# r8101 is the Linux device driver released for Realtek Fast Ethernet
+# r8125 is the Linux device driver released for Realtek 2.5 Gigabit Ethernet
 # controllers with PCI-Express interface.
 #
-# Copyright(c) 2022 Realtek Semiconductor Corp. All rights reserved.
+# Copyright(c) 2024 Realtek Semiconductor Corp. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the Free
@@ -33,24 +33,21 @@
  ***********************************************************************************/
 
 //EEPROM opcodes
-#define	RTL_EEPROM_READ_OPCODE		06
-#define	RTL_EEPROM_WRITE_OPCODE		05
-#define	RTL_EEPROM_ERASE_OPCODE		07
-#define	RTL_EEPROM_EWEN_OPCODE		19
-#define	RTL_EEPROM_EWDS_OPCODE		16
-
-#define	RTL_CLOCK_RATE	3
-
-void rtl8101_eeprom_type(struct rtl8101_private *tp);
-void rtl8101_eeprom_cleanup(struct rtl8101_private *tp);
-u16 rtl8101_eeprom_read_sc(struct rtl8101_private *tp, u16 reg);
-void rtl8101_eeprom_write_sc(struct rtl8101_private *tp, u16 reg, u16 data);
-void rtl8101_shift_out_bits(struct rtl8101_private *tp, int data, int count);
-u16 rtl8101_shift_in_bits(struct rtl8101_private *tp);
-void rtl8101_raise_clock(struct rtl8101_private *tp, u8 *x);
-void rtl8101_lower_clock(struct rtl8101_private *tp, u8 *x);
-void rtl8101_stand_by(struct rtl8101_private *tp);
-void rtl8101_set_eeprom_sel_low(struct rtl8101_private *tp);
-
+#define RTL_EEPROM_READ_OPCODE      06
+#define RTL_EEPROM_WRITE_OPCODE     05
+#define RTL_EEPROM_ERASE_OPCODE     07
+#define RTL_EEPROM_EWEN_OPCODE      19
+#define RTL_EEPROM_EWDS_OPCODE      16
 
+#define RTL_CLOCK_RATE  3
 
+void rtl8125_eeprom_type(struct rtl8125_private *tp);
+void rtl8125_eeprom_cleanup(struct rtl8125_private *tp);
+u16 rtl8125_eeprom_read_sc(struct rtl8125_private *tp, u16 reg);
+void rtl8125_eeprom_write_sc(struct rtl8125_private *tp, u16 reg, u16 data);
+void rtl8125_shift_out_bits(struct rtl8125_private *tp, int data, int count);
+u16 rtl8125_shift_in_bits(struct rtl8125_private *tp);
+void rtl8125_raise_clock(struct rtl8125_private *tp, u8 *x);
+void rtl8125_lower_clock(struct rtl8125_private *tp, u8 *x);
+void rtl8125_stand_by(struct rtl8125_private *tp);
+void rtl8125_set_eeprom_sel_low(struct rtl8125_private *tp);
